@@ -954,6 +954,8 @@ def extract_build_info_from_streamdata(testDetails):
     git_branch = None
     metadata = None
     build_variant_name = None
+    fields = [fieldname.decode() for fieldname in testDetails.keys()]
+    logging.info("Fields on stream {}".format(fields))
     git_hash = testDetails[b"git_hash"]
     if b"use_git_timestamp" in testDetails:
         use_git_timestamp = bool(testDetails[b"use_git_timestamp"].decode())
@@ -977,7 +979,7 @@ def extract_build_info_from_streamdata(testDetails):
     build_artifacts_str = "redis-server"
     build_image = testDetails[b"build_image"].decode()
     run_image = build_image
-    if b"run_image" in testDetails[b"run_image"]:
+    if b"run_image" in testDetails:
         run_image = testDetails[b"run_image"].decode()
         logging.info("detected run image info {}.".format(run_image))
     else:
